==> gcube-model-6.0.0-20251215.151726-10-sources.jar: org/gcube/resourcemanagement/model/reference/relations/isrelatedto/Manages.java <==
/**
 * 
 */
package org.gcube.resourcemanagement.model.reference.relations.isrelatedto;

import org.gcube.com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import org.gcube.informationsystem.model.reference.relations.IsRelatedTo;
import org.gcube.informationsystem.types.reference.Change;
import org.gcube.informationsystem.types.reference.TypeMetadata;
import org.gcube.informationsystem.utils.Version;
import org.gcube.resourcemanagement.model.impl.relations.isrelatedto.ManagesImpl;
import org.gcube.resourcemanagement.model.reference.entities.resources.Dataset;
import org.gcube.resourcemanagement.model.reference.entities.resources.Service;

/**
 * Manages indicates that the source {@link Service} manages the target
 * {@link Dataset}, e.g. read, manipulate, etc.
 * 
 * https://wiki.gcube-system.org/gcube/GCube_Model#Manages
 * 
 * @author Luca Frosini (ISTI - CNR)
 */
@JsonDeserialize(as=ManagesImpl.class)
@TypeMetadata(
	name = Manages.NAME, 
	description = "Manages indicates that of the source {@link Service} manages the target "
			+ "{@link Dataset}, e.g. read, manipulate, etc.",
	version = Version.MINIMAL_VERSION_STRING
)
@Change(version = Version.MINIMAL_VERSION_STRING, description = Version.MINIMAL_VERSION_DESCRIPTION)
public interface Manages<Out extends Service, In extends Dataset> 
	extends IsRelatedTo<Out, In> {
	
	/** The name of the Manages relation type. */
	public static final String NAME = "Manages"; // Manages.class.getSimpleName();
	
	/**
	 * Returns a default instance of Manages
	 * @return a default instance of Manages
	 */
	public static <Out extends Service, In extends Dataset> Manages<Out, In> getDefaultInstance(In in, Out out) {
		return new ManagesImpl<Out, In>(out, in);
	}

}

==> gcube-model-6.0.0-20251215.152539-12-sources.jar: org/gcube/resourcemanagement/model/reference/relations/isrelatedto/Manages.java <==
/**
 * 
 */
package org.gcube.resourcemanagement.model.reference.relations.isrelatedto;

import org.gcube.com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import org.gcube.informationsystem.model.reference.relations.IsRelatedTo;
import org.gcube.informationsystem.types.reference.Change;
import org.gcube.informationsystem.types.reference.TypeMetadata;
import org.gcube.informationsystem.utils.Version;
import org.gcube.resourcemanagement.model.impl.relations.isrelatedto.ManagesImpl;
import org.gcube.resourcemanagement.model.reference.entities.resources.Dataset;
import org.gcube.resourcemanagement.model.reference.entities.resources.Service;

/**
 * Manages indicates that the source {@link Service} manages the target
 * {@link Dataset}, e.g. read, manipulate, etc.
 * 
 * https://wiki.gcube-system.org/gcube/GCube_Model#Manages
 * 
 * @author Luca Frosini (ISTI - CNR)
 */
@JsonDeserialize(as=ManagesImpl.class)
@TypeMetadata(
	name = Manages.NAME, 
	description = "Manages indicates that of the source {@link Service} manages the target "
			+ "{@link Dataset}, e.g. read, manipulate, etc.",
	version = Version.MINIMAL_VERSION_STRING
)
@Change(version = Version.MINIMAL_VERSION_STRING, description = Version.MINIMAL_VERSION_DESCRIPTION)
public interface Manages<Out extends Service, In extends Dataset> 
	extends IsRelatedTo<Out, In> {
	
	/** The name of the Manages relation type. */
	public static final String NAME = "Manages"; // Manages.class.getSimpleName();
	
	/**
	 * Returns a default instance of Manages
	 * @return a default instance of Manages
	 */
	public static <Out extends Service, In extends Dataset> Manages<Out, In> getDefaultInstance(Out out, In in) {
		return new ManagesImpl<Out, In>(out, in);
	}

}
